{
    "ReleaseInfos": {
        "FileConfig": "",
        "FileCollection": "",
        "VersionNumber": "1200",
        "ReleaseDateYMD": "250220",
        "DocAbsolutePath": "https://github.com/parisolab/mathmod/wiki/documentation",
        "DocPartialPath": "../Resources/documentation/index.html"
    },
    "Parameters": {
        "AutomaticInitGrid": false,
        "IsoMaxGrid": 500,
        "InitIsoGrid": 64,
        "ParMaxGrid": 5000,
        "InitParGrid": 112,
        "ScriptEditorFontSize": 18
    },
    "StartOptions": {
        "Model": "CloseIso_1"
    },
    "ThreadsConfig": {
        "AutoDetect": true,
        "ThreadsNumber": 8,
        "MinThreadsNumber": 1,
        "MaxThreadsNumber": 256
    },
    "Localization": {
        "AutomaticDetection": true,
        "DotSymbol": "."
    },
    "CalculFactorConfig": {
        "IsoFactX": 4,
        "IsoFactY": 4,
        "IsoFactZ": 4,
        "ParFactU": 8,
        "ParFactV": 8
    },
    "OpenGlConfig": {
        "GL_SPECULAR": [50, 50, 50, 100],
        "GL_AMBIANT" : [50, 50, 50, 100],
        "GL_DIFFUSE" : [80, 80, 80, 100],
        "GL_SHININESS": 20,
        "GL_FrontFacingSupport": true
    }
}
